###################################################
### chunk number 1: loadLibrary
###################################################
#line 184 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
library(calib)


###################################################
### chunk number 2: loadData
###################################################
#line 189 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
data(HPLC)
data(ELISA)


###################################################
### chunk number 3: nameData
###################################################
#line 195 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
conc.hplc <- HPLC[,1]
resp.hplc <- HPLC[,2]
conc.elisa <- ELISA[,1]
resp.elisa <- ELISA[,2]


###################################################
### chunk number 4: plotDataAndLinFit
###################################################
#line 210 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
## Plot of the data with a std OLS fit
par(mfrow=c(1,2))
plot(conc.hplc,resp.hplc,
	xlab = "Concentration (ng/ml)",
	ylab = "Response",
	main = "HPLC data")
linmodel <- lm(resp.hplc~conc.hplc)
# The predicted response
linPredResp <- fitted(linmodel)
# Linear regression fit
lines(conc.hplc,linPredResp)

## Plot of the data with a std FPL fit
plot(log(conc.elisa),resp.elisa,
	xlab = "log(Concentration (ng/ml))",
	ylab = "Response",
	main = "ELISA data")
fplmodel <- calib.fit(conc.elisa,resp.elisa,type="log.fpl")
# The predicted response
fplPredResp <- fplmodel@fitted.values
# fpl regression fit
lines(log(conc.elisa),fplPredResp)


###################################################
### chunk number 5: plotLinRes
###################################################
#line 250 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
## Residuals from linear fit
linres <- residuals(linmodel)/summary(linmodel)[['sigma']]
plot(linPredResp,linres,
	 xlab = "Predicted Value of Mean (LS)",
	 ylab = "Standardized Residuals",
	 main = "HPLC data",
	 ylim = c(-5,5))
abline(h=0)

## Residuals from fpl fit
fplres <- fplmodel@residuals/fplmodel@sigma
plot(fplPredResp,fplres,
	xlab = "Predicted Value of Mean (FPL)",
	ylab = "Standardized Residuals",
	main = "ELISA data",
	ylim = c(-5,5))
abline(h=0)


###################################################
### chunk number 6: logHPLCplot
###################################################
#line 285 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
plot(conc.hplc,log(resp.hplc),
	 xlab = "Concentration (ng/ml)",
	 ylab = "log(Response)")


###################################################
### chunk number 7: sqrtHPLCplot
###################################################
#line 298 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
plot(conc.hplc,sqrt(resp.hplc),
	 xlab = "Concentration (ng/ml)",
	 ylab = "sqrt(Response)")


###################################################
### chunk number 8: logAbsLogPred
###################################################
#line 373 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
plot(log(linPredResp),log(abs(linres)),
	xlab = "Log(LS predicted values)",
	ylab = "Log(absolute LS residuals)",
	main = "HPLC data",
	ylim = c(-6,2))
linresmodel <- lm(log(abs(linres))~log(linPredResp))
lines(log(linPredResp),fitted(linresmodel))

plot(log(fplPredResp),log(abs(fplres)),
	xlab = "Log(FPL predicted values)",
	ylab = "Log(absolute FPL residuals)",
	main = "ELISA data",
	ylim = c(-6,2))
fplresmodel <- lm(log(abs(fplres))~log(fplPredResp))
lines(log(fplPredResp),fitted(fplresmodel))


###################################################
### chunk number 9: calib_fit
###################################################
#line 496 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
cal.fpl <- calib.fit(conc.elisa,resp.elisa,type="log.fpl")
cal.lin.pom <- calib.fit(conc.hplc,resp.hplc,type="lin.pom")
cal.fpl.pom <- calib.fit(conc.elisa,resp.elisa,type="log.fpl.pom")

linpom.fit <- cal.lin.pom@fitted.values
fplpom.fit <- cal.fpl.pom@fitted.values

sig.lin <- cal.lin.pom@sigma
sig.fpl <- cal.fpl.pom@sigma

theta.lin <- cal.lin.pom@theta
theta.fpl <- cal.fpl.pom@theta

linpom.res <- cal.lin.pom@residuals*(1/((linpom.fit^theta.lin)*sig.lin))
fplpom.res <- cal.fpl.pom@residuals*(1/((fplpom.fit^theta.fpl)*sig.fpl))


###################################################
### chunk number 10: vferesid
###################################################
#line 517 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
plot(linpom.fit,linpom.res,
	xlab = "Fitted Values (LS)",
	ylab = "Standardized Residuals",
	main = "HPLC data")
	
plot(fplpom.fit,fplpom.res,
	xlab = "Fitted Values (FPL)",
	ylab = "Standardized Residuals",
	main = "ELISA data")


###################################################
### chunk number 11: linCI
###################################################
#line 535 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
ciu <- fitted(linmodel) + summary(linmodel)$sigma*qt(.975,linmodel$df)
cil <- fitted(linmodel) - summary(linmodel)$sigma*qt(.975,linmodel$df)


###################################################
### chunk number 12: HPLCcompareCI
###################################################
#line 542 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
plot(HPLC, main = "HPLC data", sub="Without POM fit",col="blue",pch=16)
lines(conc.hplc,fitted(linmodel),col="lightblue")
lines(conc.hplc,ciu,col="lightblue",lty=2)
lines(conc.hplc,cil,col="grey",lty=2)

plot(cal.lin.pom,print=FALSE,main = "HPLC data", sub = "With POM fit",xlab = "Concentration", ylab = "Response")


###################################################
### chunk number 13: ELISAcompareCI
###################################################
#line 557 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
plot(cal.fpl,print=FALSE,main = "ELISA data", sub = "Without POM fit",xlab = "Concentration", ylab = "Response")
plot(cal.fpl.pom,print=FALSE,main = "ELISA data", sub = "With POM fit",xlab = "Concentration", ylab = "Response")


###################################################
### chunk number 14: calibCalc
###################################################
#line 611 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
calib.lin <- calib(cal.lin.pom,resp.hplc)
calib.fpl <- calib(cal.fpl.pom,resp.elisa)


###################################################
### chunk number 15: HPLCcalibPlot
###################################################
#line 620 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
plot(calib.lin,main="HPLC data")


###################################################
### chunk number 16: ELISAcalibPlot
###################################################
#line 629 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
plot(calib.fpl,main="ELISA data")


###################################################
### chunk number 17: loadLibrary
###################################################
#line 679 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
library(calib)


###################################################
### chunk number 18: loadData
###################################################
#line 684 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
data(HPLC)
data(ELISA)


###################################################
### chunk number 19: nameData
###################################################
#line 690 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
conc.hplc <- HPLC[,1]
resp.hplc <- HPLC[,2]
conc.elisa <- ELISA[,1]
resp.elisa <- ELISA[,2]


###################################################
### chunk number 20: plottingData
###################################################
#line 701 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
#par(mar = c(3.5,3.5,1.5,1.5))
plot(conc.hplc,resp.hplc,
	xlab = "Concentration (ng/ml)",
	ylab = "Response",
	main = "HPLC data")
linmodel <- lm(resp.hplc~conc.hplc)
# The predicted response
linPredResp <- fitted(linmodel)
# Linear regression fit
lines(conc.hplc,linPredResp)

## Plot of the data with a std FPL fit
#par(mar = c(3.5,3.5,1.5,1.5))
plot(log(conc.elisa),resp.elisa,
	xlab = "log(Concentration (ng/ml))",
	ylab = "Response",
	main = "ELISA data")
fplmodel <- calib.fit(conc.elisa,resp.elisa,type="log.fpl")
# The predicted response
fplPredResp <- fplmodel@fitted.values
# fpl regression fit
lines(log(conc.elisa),fplPredResp)


###################################################
### chunk number 21: plottingLinRes
###################################################
#line 738 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
## Residuals from linear fit
linres <- residuals(linmodel)/summary(linmodel)[['sigma']]
plot(linPredResp,linres,
	 xlab = "Predicted Value of Mean (LS)",
	 ylab = "Standardized Residuals",
	 main = "HPLC data",
	 ylim = c(-5,5))
abline(h=0)

## Residuals from fpl fit
fplres <- fplmodel@residuals/fplmodel@sigma
plot(fplPredResp,fplres,
	xlab = "Predicted Value of Mean (FPL)",
	ylab = "Standardized Residuals",
	main = "ELISA data",
	ylim = c(-5,5))
abline(h=0)


###################################################
### chunk number 22: plottingLogHPLC
###################################################
#line 771 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
plot(conc.hplc,log(resp.hplc),
	 xlab = "Concentration (ng/ml)",
	 ylab = "log(Response)")


###################################################
### chunk number 23: plottingSqrtHPLC
###################################################
#line 782 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
plot(conc.hplc,sqrt(resp.hplc),
	 xlab = "Concentration (ng/ml)",
	 ylab = "sqrt(Response)")


###################################################
### chunk number 24: plottingLogAbsLog
###################################################
#line 800 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
plot(log(linPredResp),log(abs(linres)),
	xlab = "Log(LS predicted values)",
	ylab = "Log(absolute LS residuals)",
	main = "HPLC data",
	ylim = c(-6,2))
linresmodel <- lm(log(abs(linres))~log(linPredResp))
lines(log(linPredResp),fitted(linresmodel))

plot(log(fplPredResp),log(abs(fplres)),
	xlab = "Log(FPL predicted values)",
	ylab = "Log(absolute FPL residuals)",
	main = "ELISA data",
	ylim = c(-6,2))
fplresmodel <- lm(log(abs(fplres))~log(fplPredResp))
lines(log(fplPredResp),fitted(fplresmodel))


###################################################
### chunk number 25: calib_fitFuns
###################################################
#line 827 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
cal.fpl <- calib.fit(conc.elisa,resp.elisa,type="log.fpl")
cal.lin.pom <- calib.fit(conc.hplc,resp.hplc,type="lin.pom")
cal.fpl.pom <- calib.fit(conc.elisa,resp.elisa,type="log.fpl.pom")

linpom.fit <- cal.lin.pom@fitted.values
fplpom.fit <- cal.fpl.pom@fitted.values

sig.lin <- cal.lin.pom@sigma
sig.fpl <- cal.fpl.pom@sigma

theta.lin <- cal.lin.pom@theta
theta.fpl <- cal.fpl.pom@theta

linpom.res <- cal.lin.pom@residuals*(1/((linpom.fit^theta.lin)*sig.lin))
fplpom.res <- cal.fpl.pom@residuals*(1/((fplpom.fit^theta.fpl)*sig.fpl))


###################################################
### chunk number 26: plottingVferesid
###################################################
#line 847 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
#par(mar = c(3.5,3.5,1.5,1.5))
plot(linpom.fit,linpom.res,
	xlab = "Fitted Values (LS)",
	ylab = "Standardized Residuals",
	main = "HPLC data")

#par(mar = c(3.5,3.5,1.5,1.5))	
plot(fplpom.fit,fplpom.res,
	xlab = "Fitted Values (FPL)",
	ylab = "Standardized Residuals",
	main = "ELISA data")


###################################################
### chunk number 27: linCIFuns
###################################################
#line 866 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
ciu <- fitted(linmodel) + summary(linmodel)$sigma*qt(.975,linmodel$df)
cil <- fitted(linmodel) - summary(linmodel)$sigma*qt(.975,linmodel$df)


###################################################
### chunk number 28: plottingHPLCcompareCI
###################################################
#line 871 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
#par(mar = c(3.5,3.5,1.5,1.5))
plot(HPLC, main = "HPLC data", sub="Without POM fit",col="blue",pch=16)
lines(conc.hplc,fitted(linmodel),col="lightblue")
lines(conc.hplc,ciu,col="lightblue",lty=2)
lines(conc.hplc,cil,col="grey",lty=2)

#par(mar = c(3.5,3.5,1.5,1.5))
plot(cal.lin.pom,print=FALSE,main = "HPLC data", sub = "With POM fit",xlab = "Concentration", ylab = "Response")


###################################################
### chunk number 29: plottingELISAcompareCI
###################################################
#line 885 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
par(mfrow=c(1,2))
#par(mar = c(3.5,3.5,1.5,1.5))
plot(cal.fpl,print=FALSE,main = "ELISA data", sub = "Without POM fit",xlab = "Concentration", ylab = "Response")

#par(mar = c(3.5,3.5,1.5,1.5))
plot(cal.fpl.pom,print=FALSE,main = "ELISA data", sub = "With POM fit",xlab = "Concentration", ylab = "Response")


###################################################
### chunk number 30: calibCalcFun
###################################################
#line 897 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
calib.lin <- calib(cal.lin.pom,resp.hplc)
calib.fpl <- calib(cal.fpl.pom,resp.elisa)


###################################################
### chunk number 31: plottingHPLCcalibPlot
###################################################
#line 904 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
plot(calib.lin,main="HPLC data")


###################################################
### chunk number 32: plottingELISAcalibPlot
###################################################
#line 910 "d:/Rcompile/CRANpkg/local/2.12/calib/inst/doc/HowTo-calib.Rnw"
plot(calib.fpl,main="ELISA data")


